@@ -1,4 +1,5 @@
 {-# LANGUAGE Trustworthy #-}
+{-# OPTIONS_GHC -fno-warn-name-shadowing #-}
 
 {- arch-tag: Generic Server Support
 Copyright (c) 2004-2011 John Goerzen <jgoerzen@complete.org>
@@ -45,11 +46,30 @@ module Network.SocketServer(-- * Generic Options and Types
                                      handleHandler
                                     )
 where
-import           Control.Concurrent
-import           Network.BSD
-import           Network.Socket
-import           Network.Utils
-import           System.IO
+import Control.Concurrent ( forkIO )
+import Data.Functor (void)
+import Network.BSD
+    ( getProtocolNumber, Family(AF_INET), HostAddress, PortNumber )
+import Network.Socket
+    ( socketToHandle,
+      setSocketOption,
+      accept,
+      bind,
+      getSocketName,
+      listen,
+      socket,
+      close,
+      SocketOption(ReuseAddr),
+      SockAddr(SockAddrInet),
+      Socket,
+      SocketType(Stream) )
+import Network.Utils ( showSockAddr )
+import System.IO
+    ( Handle,
+      hClose,
+      hSetBuffering,
+      BufferMode(LineBuffering),
+      IOMode(ReadWriteMode) )
 import qualified System.Log.Logger
 
 {- | Options for your server. -}
@@ -111,11 +131,10 @@ closeSocketServer ss =
 
 {- | Handle one incoming request from the given 'SocketServer'. -}
 handleOne :: SocketServer -> HandlerT -> IO ()
-handleOne ss func =
-    let opts = (optionsSS ss)
-        in    do a <- accept (sockSS ss)
-                 localaddr <- getSocketName (fst a)
-                 func (fst a) (snd a) localaddr
+handleOne ss func = do
+    a <- accept (sockSS ss)
+    localaddr <- getSocketName (fst a)
+    func (fst a) (snd a) localaddr
 
 {- | Handle all incoming requests from the given 'SocketServer'. -}
 serveForever :: SocketServer -> HandlerT -> IO ()
@@ -168,9 +187,8 @@ loggingHandler hname prio nexth socket r_sockaddr l_sockaddr =
 -- make the server multi-tasking.
 threadedHandler :: HandlerT             -- ^ Handler to call in the new thread
                 -> HandlerT             -- ^ Resulting handler
-threadedHandler nexth socket r_sockaddr l_sockaddr=
-    do forkIO (nexth socket r_sockaddr l_sockaddr)
-       return ()
+threadedHandler nexth socket r_sockaddr l_sockaddr = void $
+    forkIO (nexth socket r_sockaddr l_sockaddr)
 
 {- | Give your handler function a Handle instead of a Socket.
 
