@@ -13,7 +13,7 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2005-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable
 
 Provide a stat-like structure for use in MissingH.  Especially
@@ -21,19 +21,36 @@ useful with HVFS and on Windows.  See also "System.IO.WindowsCompat".
 
 -}
 
-module System.IO.StatCompat
-where
-import           System.Posix.Consts
-import           System.Posix.Types
+module System.IO.StatCompat where
+
+import safe System.Posix.Consts
+    ( blockSpecialMode,
+      characterSpecialMode,
+      namedPipeMode,
+      regularFileMode,
+      directoryMode,
+      fileTypeModes,
+      socketMode,
+      symbolicLinkMode )
+import safe System.Posix.Types
+    ( DeviceID,
+      EpochTime,
+      FileID,
+      FileMode,
+      FileOffset )
+
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-import           System.Posix.Files  (intersectFileModes)
-#endif
-import           Data.Bits           ((.&.))
+import safe System.Posix.Types ( LinkCount, UserID, GroupID )
+import safe System.Posix.Files ( intersectFileModes )
+#else
+import safe Data.Bits          ( (.&.) )
 
-#if (defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
 type LinkCount = Int
 type UserID = Int
 type GroupID = Int
+
+intersectFileModes :: FileMode -> FileMode -> FileMode
+intersectFileModes m1 m2 = m1 .&. m2
 #endif
 
 data FileStatusCompat =
@@ -62,8 +79,3 @@ isRegularFile = sc_helper regularFileMode
 isDirectory = sc_helper directoryMode
 isSymbolicLink = sc_helper symbolicLinkMode
 isSocket = sc_helper socketMode
-
-#if (defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-intersectFileModes :: FileMode -> FileMode -> FileMode
-intersectFileModes m1 m2 = m1 .&. m2
-#endif
