@@ -12,7 +12,7 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2005-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable
 
 Exports some POSIX constants and functions that are not exported in fptools
@@ -21,7 +21,8 @@ by default.
 -}
 
 module System.Posix.Consts where
-import           System.Posix.Types
+
+import safe System.Posix.Types ( FileMode )
 
 blockSpecialMode :: FileMode
 blockSpecialMode = 0o0060000
@@ -46,5 +47,3 @@ socketMode = 0o0140000
 
 symbolicLinkMode :: FileMode
 symbolicLinkMode = 0o0120000
-
-
